package main

import (
	"flag"
	"fmt"
	"os"

	tea "github.com/charmbracelet/bubbletea"
)

const (
	defaultProfileFilename = "coverage.out"
)

var (
	version string
	commit  string
	date    string
)

func main() {
	if err := run(); err != nil {
		fmt.Fprintf(os.Stderr, "%v\n", err)
		os.Exit(1)
	}
}

func run() error {
	var (
		showVersion     bool
		profileFilename string
	)

	flag.BoolVar(&showVersion, "version", false, "show version")
	flag.StringVar(
		&profileFilename, "profile", defaultProfileFilename,
		"File name of coverage profile generated by go test -coverprofile coverage.out",
	)
	flag.Parse()

	if showVersion {
		fmt.Printf("version: %s, commit %s, date %s\n", version, commit, date)
		return nil
	}

	m := model{
		activeView:      activeViewList,
		helpState:       helpStateShort,
		profileFilename: profileFilename,
	}

	if os.Getenv("DEBUG") != "" {
		f, err := tea.LogToFile("bubbletea.log", "gocovsh")
		if err != nil {
			return fmt.Errorf("failed to setup logger: %w", err)
		}

		defer func() { _ = f.Close() }()
	}

	if err := tea.NewProgram(m, tea.WithAltScreen()).Start(); err != nil {
		return fmt.Errorf("failed to start program: %w", err)
	}

	return nil
}
